Skip to contents

Median of case-wise CRPS values. Lower values are better. It is a robust descriptive summary when a few large errors dominate mean CRPS.

Usage

median_crps(
  obs,
  distribution = NULL,
  pred = NULL,
  predictive_sd = NULL,
  na.rm = TRUE
)

Arguments

obs

Numeric observation vector.

distribution

Numeric matrix/data frame of equally weighted predictive samples, one row per observation.

pred, predictive_sd

Mean and strictly positive predictive SD for normal predictive distributions.

na.rm

Logical; remove incomplete observation/distribution rows?

Value

One numeric median CRPS value.

Details

$$\mathrm{median\ CRPS} = \mathrm{median}(\mathrm{CRPS}_i)$$

It has response units; lower values are better. Unlike mean CRPS, it describes a typical case and is less sensitive to a small number of very poor predictive distributions. Median aggregation is a robust descriptive summary but should not replace mean CRPS for formal comparisons based on proper scoring rules.

References

Hersbach, H. (2000). Decomposition of the continuous ranked probability score for ensemble prediction systems. Weather and Forecasting, 15, 559-570. doi:10.1175/1520-0434(2000)015%3C0559:DOTCRP%3E2.0.CO;2

Examples

median_crps(0, distribution = matrix(c(-1, 1), nrow = 1))
#> [1] 0.5